@@ -1,13 +1,7 @@
 package Class::Accessor::Fast;
-
+use base 'Class::Accessor';
 use strict;
-use vars qw($VERSION @ISA);
-$VERSION = '0.02';
-require Class::Accessor;
-@ISA = qw(Class::Accessor);
-
-
-=pod
+$Class::Accessor::Fast::VERSION = $Class::Accessor::VERSION;
 
 =head1 NAME
 
@@ -18,22 +12,23 @@ Class::Accessor::Fast - Faster, but less expandable, accessors
   package Foo;
   use base qw(Class::Accessor::Fast);
 
-  # The rest as Class::Accessor except no set() or get().
+  # The rest is the same as Class::Accessor but without set() and get().
 
 =head1 DESCRIPTION
 
-This is a somewhat faster, but less expandable, version of
-Class::Accessor.  Class::Accessor's generated accessors require two
-method calls to accompish their task (one for the accessor, another
-for get() or set()).  Class::Accessor::Fast eliminates calling
-set()/get() and does the access itself, resulting in a somewhat faster
-accessor.
+This is a faster but less expandable version of Class::Accessor.
+Class::Accessor's generated accessors require two method calls to accompish
+their task (one for the accessor, another for get() or set()).
+Class::Accessor::Fast eliminates calling set()/get() and does the access itself,
+resulting in a somewhat faster accessor.
 
 The downside is that you can't easily alter the behavior of your
 accessors, nor can your subclasses.  Of course, should you need this
 later, you can always swap out Class::Accessor::Fast for
 Class::Accessor.
 
+Read the documentation for Class::Accessor for more info.
+
 =cut
 
 sub make_accessor {
@@ -41,10 +36,8 @@ sub make_accessor {
 
     return sub {
         my $self = shift;
-        if(@_) {
-            $self->{$field} = (@_ == 1 ? $_[0] : [@_]);
-        }
-        return $self->{$field};
+        return $self->{$field} unless @_;
+        $self->{$field} = (@_ == 1 ? $_[0] : [@_]);
     };
 }
 
@@ -53,17 +46,11 @@ sub make_ro_accessor {
     my($class, $field) = @_;
 
     return sub {
-        my $self = shift;
-
-        if(@_) {
-            my $caller = caller;
-            require Carp;
-            Carp::croak("'$caller' cannot alter the value of '$field' on ".
-                        "objects of class '$class'");
-        }
-        else {
-            return $self->{$field};
-        }
+        return $_[0]->{$field} unless @_ > 1;
+        my $caller = caller;
+        require Carp;
+        Carp::croak("'$caller' cannot alter the value of '$field' on ".
+                    "objects of class '$class'");
     };
 }
 
@@ -72,7 +59,7 @@ sub make_wo_accessor {
     my($class, $field) = @_;
 
     return sub {
-        my($self) = shift;
+        my $self = shift;
 
         unless (@_) {
             my $caller = caller;
@@ -87,23 +74,26 @@ sub make_wo_accessor {
 }
 
 
-=pod
-
 =head1 EFFICIENCY
 
 L<Class::Accessor/EFFICIENCY> for an efficiency comparison.
 
+=head1 AUTHORS
 
-=head1 AUTHOR
+Copyright 2005 Marty Pauley <marty+perl@kasei.com>
+
+This program is free software; you can redistribute it and/or modify it under
+the same terms as Perl itself.  That means either (a) the GNU General Public
+License or (b) the Artistic License.
+
+=head2 ORIGINAL AUTHOR
 
 Michael G Schwern <schwern@pobox.com>
 
-
 =head1 SEE ALSO
 
 L<Class::Accessor>
 
 =cut
 
-
 1;
